Chess Self-Coach

Sample data — Install the app to train on your own games

Loading training data...

See moves played during the game

Analyzing...

## Edit Config

Lichess username: Chess.com username: Default analysis depth: Blunder threshold (cp):

## Settings

Positions per session: Analysis depth: Difficulty:

## Session Complete

## Raw Data Summary

## Project Status

## Cleanup Studies

## Refresh Training

## PGN Validation

## Coaching Journal

## Chess Self-Coach